@@ -6,11 +6,9 @@ Wherever smart people work, doors are unlocked. -- Steve Wozniak
 # Set default logging handler to avoid "No handler found" warnings.
 import logging
 
-from .article import Article, ArticleException, ArticleExecutor
+from .article import Article, ArticleException
 from .configuration import Configuration
 from .mthreading import NewsPool
-from .source import Source
-from .sources import Sources
 from .utils import get_languages, get_available_languages, fulltext
 from .version import __version__
 
