@@ -1,6 +1,4 @@
 from .article_process import ArticleProcess
-from .article_pool import ArticlePool
-from .article_progress import ArticleProgress
 from .countries import Countries
 from .file_types import FileTypes
 from .health import Health
